@@ -9,8 +9,8 @@ extern struct tetris2p {
 	int delay;
 	char clearedlines[4];
 	char nul;
-	char garbage[3];
-	char x1, x2;
+	signed char garbage[3];
+	signed char x1, x2;
 	short b1, b2;
 } tetris2p[2];
 
