@@ -25,7 +25,7 @@ static int islatin1(const char *s)
 	s += 4;
 	if (*s == '-')
 		s++;
-	return !strcmp(s, "1");
+	return *s == '1' && (!s[1] || s[1] == '5');
 }
 
 void getlang()
