@@ -25,18 +25,35 @@ static int gm_mode(int k, int *pos)
 int startup_menu(int i, int x, int y)
 {
 	union val v;
-	const char *menu[6] = {
+	const char *menu[7] = {
 		"1-Player Game",
 		"2-Player Game",
+#ifdef INET
+		"Netplay",
+#endif
 		"Mode",
 		"-------------",
 		"Options",
 		"Highscores"
 	};
-	menuhandler handlers[6] = {0, 0, gm_mode};
-	i = openmenu(menu, 6, i, x, y, handlers);
-	if (i==1 || i==2) {
-		v.integ = i | getopt_int("", "mode") & MODE_BTYPE;
+	menuhandler handlers[7] = {0, 0,
+#ifdef INET
+		0,
+#endif
+		gm_mode};
+	i = openmenu(menu,
+#ifdef INET
+				1 +
+#endif
+				6, i, x, y, handlers);
+	if (i && i <= 3) {
+#ifdef INET
+		if (i==3)
+			v.integ = MODE_2PLAYER | MODE_NETWORK;
+		else
+#endif
+		v.integ = i;
+		v.integ |= getopt_int("", "mode") & MODE_BTYPE;
 		setoption("", "mode", v, 0);
 	}
 	return i;
